
/*
  Copyright (C) 2013 Jolla Ltd.
  Contact: Thomas Perl <thomas.perl@jollamobile.com>
  All rights reserved.

  You may use this file under the terms of BSD license as follows:

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions are met:
    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.
    * Neither the name of the Jolla Ltd nor the
      names of its contributors may be used to endorse or promote products
      derived from this software without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
  DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR
  ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
  (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

import QtQuick 2.0
import Sailfish.Silica 1.0
import "pages/JavaScriptHelper.js" as AltMyScript
import QtQuick.XmlListModel 2.0

ApplicationWindow
{
    XmlListModel {
        id: forecast
        source: "http://api.openweathermap.org/data/2.5/forecast/daily?q=Helsinki,fi&units=metric&mode=xml"
        query: "/weatherdata/forecast/time[contains(@day,"+AltMyScript.getData()+")]"

        XmlRole {
            name: "day"
            query: "@day/string()"
        }
        XmlRole {
            name: "temperature"
            query: "temperature/@day/string()"
        }
        XmlRole {
            name: "symbol"
            query: "symbol/@var/string()"
        }

        onStatusChanged: {
            if (status === XmlListModel.Ready) {
                var today = get(0)
                coverImage.source = "http://openweathermap.org/img/w/" + today.symbol + ".png"
                weatherImage.source = "http://openweathermap.org/img/w/" + today.symbol + ".png"
                temperature.text = AltMyScript.stringtrunc(today.temperature) + " °C"
            }
        }
    }
    XmlListModel {
        id: time
        source: "http://api.worldweatheronline.com/free/v1/tz.ashx?q=Helsinki&format=xml&key=xgynekmsfwcg5e3rwfu3mq5a"
        query: "/data/time_zone"

        XmlRole {
            name: "localtime"
            query: "localtime/string()"
        }

        onStatusChanged: {
            if (status === XmlListModel.Ready) {
                var today = get(0)
                localTime.text = today.localtime
            }
        }
    }
    XmlListModel {
        id: suninfo
        source: "http://api.openweathermap.org/data/2.5/forecast/daily?q=Helsinki,fi&units=metric&mode=xml"
        query: "/weatherdata/sun"

        XmlRole {
            name: "sunset"
            query: "@set/string()"
        }
        XmlRole {
            name: "rise"
            query: "@rise/string()"
        }


        onStatusChanged: {
            if (status === XmlListModel.Ready) {
                var today = get(0)
                sunrise.text = AltMyScript.editSunRiseSunSet(today.rise)
                sunset.text = AltMyScript.editSunRiseSunSet(today.sunset)
            }
        }
    }
    initialPage: Page {
        Timer{
            id: filterTimer
            interval:30000
            running: true
            repeat: true
            onTriggered: {
                 time.reload();
                      }
        }

        SilicaFlickable{
            PullDownMenu {
                MenuItem {
                    text: "Blogs"
                    onClicked: pageStack.push(Qt.resolvedUrl("pages/Blogs.qml"))
                }
             //   MenuItem {
             //       text: "Transportation"
            //        onClicked: pageStack.push(Qt.resolvedUrl("pages/TransportationBusRoutes.qml"))
            //    }
                MenuItem {
                    text: "Accomodation"
                    onClicked: pageStack.push(Qt.resolvedUrl("pages/Accomodations.qml"))
                }
                MenuItem {
                    text: "Events"
                    onClicked: pageStack.push(Qt.resolvedUrl("pages/Events.qml"))
                }
                MenuItem {
                    text: "Activities"
                    onClicked: pageStack.push(Qt.resolvedUrl("pages/Activities.qml"))
                }
                MenuItem {
                    text: "Attractions"
                    onClicked: pageStack.push(Qt.resolvedUrl("pages/Attractions.qml"))
                }

            }

            anchors.fill: parent
            contentHeight: column.height + Theme.paddingLarge

             VerticalScrollDecorator {}

             Column {
                 id: column
                 width: page.width
                 spacing: Theme.paddingLarge

                 PageHeader {
                     title: "Easy Tourist"

                 }
                 Label {
                     x: Theme.paddingLarge
                     text: "Welcome to Helsinki!"
                     color: Theme.secondaryHighlightColor
                     horizontalAlignment: text.AlignHCenter
                     //horizontalAlignment: text.AlignmentH.centerAlignment
                     font.pixelSize: Theme.fontSizeExtraLarge
                    // font.bold: text
                 }
                 Label{
                     id:localTime
                     x: Theme.paddingLarge
                     color: Theme.secondaryHighlightColor
                     font.pixelSize: Theme.fontSizeLarge
                     horizontalAlignment: localTime.AlignHCenter
                 }
                 Row{

                    Image {
                        id:weatherImage
                        height: Theme.itemSizeExtraLarge
                        width: Theme.itemSizeExtraLarge
                        horizontalAlignment: weatherImage.AlignHCenter
                        MouseArea{
                            anchors.fill: parent
                            onClicked: pageStack.push(Qt.resolvedUrl("pages/WeatherPage.qml"))
                        }

                    }

                 Label {
                       id: temperature
                       x: Theme.paddingLarge
                       //
                       color: Theme.secondaryHighlightColor
                       font.pixelSize: Theme.fontSizeMedium
                       horizontalAlignment: temperature.AlignHCenter
                   }
                 }
                 Row{
                    Column{
                     Label{
                        x: Theme.paddingLarge
                        color: Theme.secondaryHighlightColor
                        font.pixelSize: Theme.fontSizeMedium
                        text:"Sunrise: "
                    }}
                   Column{
                    Label{
                        id:sunrise
                        x: Theme.paddingLarge
                        color: Theme.secondaryHighlightColor
                        font.pixelSize: Theme.fontSizeMedium
                    }}
                }
                 Row{
                     Column{
                    Label{
                        x: Theme.paddingLarge
                        color: Theme.secondaryHighlightColor
                        font.pixelSize: Theme.fontSizeMedium
                        text:"Sunset: "

                    }
                     }
                    Column{
                    Label{
                        id:sunset
                        x: Theme.paddingLarge
                        color: Theme.secondaryHighlightColor
                        font.pixelSize: Theme.fontSizeMedium

                    }
                    }

             }


             }
        }
    }

    cover: CoverBackground {
        Column {
            anchors.centerIn: parent
            Image {
                id: coverImage
                height: Theme.itemSizeLarge
                width: Theme.itemSizeLarge
            }

        }
    }
}



